#
# spec file for package python-future
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-future
Version:        0.18.3
Release:        4.3
Summary:        Single-source support for Python 3 and 2
# See https://github.com/PythonCharmers/python-future/issues/242 for PSF licensing
License:        MIT AND Python-2.0
URL:            https://python-future.org
Source0:        https://files.pythonhosted.org/packages/source/f/future/future-%{version}.tar.gz
Source100:      python-future-rpmlintrc
# PATCH-FIX-UPSTREAM python38-pow.patch gh#PythonCharmers/python-future#474 mcepl@suse.com
Patch0:         python38-pow.patch
# UPSTREAM ISSUE gh#PythonCharmers/python-future#508
Patch1:         future-correct-mimetype.patch
# PATCH-FIX-UPSTREAM python39-build.patch gh#PythonCharmers/python-future#578 mcepl@suse.com
# Overcome incompatibilites with python 3.9
Patch2:         python39-build.patch
# PATCH-FIX-UPSTREAM 619-test-zero-byte.patch gh#PythonCharmers/python-future#618 mcepl@suse.com
# incompatibilities with 3.11.4
Patch3:         619-test-zero-byte.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{suse_version} >= 1550 || (0%{suse_version} == 1500 && 0%{?sle_version} >= 150400)
BuildRequires:  %{python_module dbm}
%else
BuildRequires:  python3-dbm
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Future is a compatibility layer between Python 2 and Python 3.
It allows you to use a single Python 3.x-compatible codebase to
support both Python 2 and Python 3.

%prep
%autosetup -p1 -n future-%{version}
sed -i -e '/^#!\//, 1d' src/future/backports/test/pystone.py

%build
%pyproject_wheel

%install
%pyproject_install

%python_clone -a %{buildroot}%{_bindir}/futurize
%python_clone -a %{buildroot}%{_bindir}/pasteurize

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%{python_install_alternative futurize pasteurize}

%postun
%python_uninstall_alternative futurize

%check
# test_moves_urllib_request_http or test_urllib_request_http require internet
# test_geturl or test_main fail only on Leap 42.3 and SLE 12 SP4
%{python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m pytest \
  -k 'not (test_moves_urllib_request_http or test_urllib_request_http or test_geturl or test_main)'
}

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/futurize
%python_alternative %{_bindir}/pasteurize
%{python_sitelib}/future-%{version}*-info
%{python_sitelib}/future
%{python_sitelib}/libfuturize
%{python_sitelib}/libpasteurize
%{python_sitelib}/past

%changelog
* Tue Jul  4 2023 Matej Cepl <mcepl@suse.com>
- Add 619-test-zero-byte.patch to fix
  gh#PythonCharmers/python-future#618.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Feb  1 2023 Dirk Müller <dmueller@suse.com>
- pull in dbm for all flavors on SLE15 SP4+ as well
* Sat Jan 21 2023 Dirk Müller <dmueller@suse.com>
- update to 0.18.3:
  * Backport fix for bpo-38804 (c91d70b)
  * Fix bug in fix_print.py fixer (dffc579)
  * Fix bug in fix_raise.py fixer (3401099)
  * Fix newint bool in py3 (fe645ba)
  * Fix bug in super() with metaclasses (6e27aac)
  * docs: fix simple typo, reqest -> request (974eb1f)
  * Correct eq (c780bf5)
  * Pass if lint fails (2abe00d)
  * fix order (f96a219)
  * Add flake8 to image (046ff18)
  * Make lint.sh executable (58cc984)
  * Add docker push to optimize CI (01e8440)
  * Build System (42b3025)
  * Add docs build status badge to README.md (3f40bd7)
  * Use same docs requirements in tox (18ecc5a)
  * Add docs/requirements.txt (5f9893f)
  * Add PY37_PLUS, PY38_PLUS, and PY39_PLUS (bee0247)
  * fix 2.6 test, better comment (ddedcb9)
  * fix 2.6 test (3f1ff7e)
  * remove nan test (4dbded1)
  * include list test values (e3f1a12)
  * fix other python2 test issues (c051026)
  * fix missing subTest (f006cad)
  * import from old imp library on older python versions (fc84fa8)
  * replace fstrings with format for python 3.4,3.5 (4a687ea)
  * minor style/spelling fixes (8302d8c)
  * improve cmp function, add unittest (0d95a40)
  * Pin typing==3.7.4.1 for Python 3.3 compatiblity (1a48f1b)
  * Fix various py26 unit test failures (9ca5a14)
  * Add initial contributing guide with docs build instruction (e55f915)
  * Add docs building to tox.ini (3ee9e7f)
  * Support NumPy's specialized int types in builtins.round (b4b54f0)
  * Added r""" to the docstring to avoid warnings in python3 (5f94572)
  * Add subclasscheck for past.types.basestring (c9bc0ff)
  * Correct example in README (681e78c)
  * Add simple documentation (6c6e3ae)
  * Add pre-commit hooks (a9c6a37)
  * Handling of next and next by future.utils.get_next was reversed (52b0ff9)
  * Add a test for our fix (461d77e)
  * Compare headers to correct definition of str (3eaa8fd)
  * Add support for negative ndigits in round; additionally, fixing a bug so
    that it handles passing in Decimal properly (a4911b9)
  * Add tkFileDialog to future.movers.tkinter (f6a6549)
  * Sort before comparing dicts in TestChainMap (6126997)
  * Fix typo (4dfa099)
  * Fix formatting in "What's new" (1663dfa)
  * Fix typo (4236061)
  * Avoid DeprecationWarning caused by invalid escape (e4b7fa1)
  * Fixup broken link to external django documentation re: porting to Python 3
    and unicode_literals (d87713e)
  * Fixed newdict checking version every time (99030ec)
  * Add count from 2.7 to 2.6 (1b8ef51)
- drop CVE-2022-40899.patch (upstream)
* Thu Jan  5 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add CVE-2022-40899.patch to fix REDoS in http.cookiejar
  gh#PythonCharmers/python-future#610
  bsc#1206673
* Fri Mar 12 2021 Matej Cepl <mcepl@suse.com>
- Add python39-build.patch to avoid test failures
  (gh#PythonCharmers/python-future#578).
* Thu Dec  3 2020 Benjamin Greiner <code@bnavigator.de>
- Need dbm for more than one python3 flavor
  gh#openSUSE/python-rpm-macros#66
* Thu Dec  5 2019 Matej Cepl <mcepl@suse.com>
- Update to 0.18.2:
  - Fix min/max functions with generators, and 'None' default (PR #514)
  - Use BaseException in raise_() (PR #515)
  - Fix builtins.round() for Decimals (Issue #501)
  - Fix raise_from() to prevent failures with immutable classes (PR #518)
  - Make FixInput idempotent (Issue #427)
  - Fix type in newround (PR #521)
  - Support mimetype guessing in urllib2 for Py3.8+ (Issue #508)
  - fix for raise_() when passed an exception that's not an
    Exception (e.g. BaseException subclasses)
- Rebase future-correct-mimetype.patch to revert incorrect fix in
  gh#PythonCharmers/python-future#508
* Mon Oct 14 2019 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.18.0.
- Remove python38-compat.patch, already included.
- Add future-correct-mimetype.patch, since Python 3.8 is able to detect
  the MIME type now.
* Wed Oct  2 2019 Matej Cepl <mcepl@suse.com>
- Add python38-compat.patch to fix compatibility with Python 3.8
  gh#PythonCharmers/python-future#447
- Add python38-pow.patch not to expect exception on new available
  parameters for Python 3.8. gh#PythonCharmers/python-future#474
* Tue May  7 2019 John Vandenberg <jayvdb@gmail.com>
- Change License from MIT to MIT and Python-2.0
* Mon Mar 11 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 16 2018 Todd R <toddrme2178@gmail.com>
- Update to version 0.17.1
  * This release address a packaging error because of an erroneous declaration that
    any built wheels are universal.
- Update to version 0.17.0
  * Fix ``from collections import ChainMap`` after install_aliases() (issue #226)
  * Fix multiple import from ``__future__`` bug in futurize (issue #113)
  * Add support for proper %%s formatting of newbytes
  * Properly implement iterator protocol for newrange object
  * Fix ``past.translation`` on read-only file systems
  * Fix Tkinter import bug introduced in Python 2.7.4 (issue #262)
  * Correct TypeError to ValueError in a specific edge case for newrange
  * Support inequality tests betwen newstrs and newbytes
  * Add type check to __get__ in newsuper
  * Fix fix_divsion_safe to support better conversion of complex expressions, and
    skip obvious float division.
* Thu Apr  6 2017 toddrme2178@gmail.com
- Implement single-spec version
* Fri Nov 25 2016 mimi.vx@gmail.com
- update to 0.16.0
  * Fix newbytes constructor bug.
  * Fix semantics of bool() with newobject.
  * Fix standard_library.install_aliases() on PyPy
  * Fix assertRaises for pow and compile` on Python 3.5.
  * Fix return argument of future.utils.ensure_new_type
  if conversion to new type does not exist.
  * Add missing cmp_to_key for Py2.6.
  * Allow the old_div fixer to be disabled.
  * Improve compatibility with Google App Engine.
  * Add some missing imports to the tkinter and tkinter.filedialog
  package namespaces
  * Fix raise_from on PY3 when the exception cannot be recreated from its repr.
* Tue Oct 11 2016 ms@suse.com
- Tracker changelog entry to add python-future to SLE12 (bnc#999200)
* Wed Sep 21 2016 okurz@suse.com
- Fix rpm uninstall warnings by removing alternatives in postun as
  discussed in https://build.opensuse.org/request/show/427095
* Thu Sep 15 2016 toddrme2178@gmail.com
- Fix update-alternatives usage.
* Fri Sep  9 2016 glin@suse.com
- Remove %%ghost from %%{_bindir}/futurize and %%{_bindir}/pasteurize
  (fate#320644)
* Mon Dec 14 2015 glin@suse.com
- initial import: 0.15.2 (fate#320644)
